@@ -1,5 +1,5 @@
 package Test::HTML::Tidy::Recursive;
-$Test::HTML::Tidy::Recursive::VERSION = '0.2.1';
+$Test::HTML::Tidy::Recursive::VERSION = '0.4.0';
 use strict;
 use warnings;
 use 5.008;
@@ -138,7 +138,7 @@ HTML::Tidy .
 
 =head1 VERSION
 
-version 0.2.1
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,7 @@ functionality.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.4.0
 
 =head1 METHODS
 
@@ -260,7 +260,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Test-HTML-Tidy-Recursive>
+L<https://metacpan.org/release/Test-HTML-Tidy-Recursive>
 
 =item *
 
@@ -296,14 +296,6 @@ L<http://cpanratings.perl.org/d/Test-HTML-Tidy-Recursive>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Test-HTML-Tidy-Recursive>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -314,7 +306,7 @@ L<http://cpants.cpanauthors.org/dist/Test-HTML-Tidy-Recursive>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/T/Test-HTML-Tidy-Recursive>
 
